searchData={"items":[{"type":"module","title":"Atex.AtURI","doc":"Struct and helper functions for manipulating `at://` URIs, which identify\nspecific records within the AT Protocol. For more information on the URI\nscheme, refer to the ATProto spec: https://atproto.com/specs/at-uri-scheme.\n\nThis module only supports the restricted URI syntax used for the Lexicon\n`at-uri` type, with no support for query strings or fragments. If/when the\nfull syntax gets widespread use, this module will expand to accomodate them.\n\nBoth URIs using DIDs and handles (\"example.com\") are supported.","ref":"Atex.AtURI.html"},{"type":"function","title":"Atex.AtURI.match?/1","doc":"Check if a string is a valid `at://` URI.","ref":"Atex.AtURI.html#match?/1"},{"type":"function","title":"Examples - Atex.AtURI.match?/1","doc":"iex> Atex.AtURI.match?(\"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\")\n    true\n\n    iex> Atex.AtURI.match?(\"at://did:web:comet.sh\")\n    true\n\n    iex> Atex.AtURI.match?(\"at://ovyerus.com/sh.comet.v0.feed.track\")\n    true\n\n    iex> Atex.AtURI.match?(\"gobbledy gook\")\n    false","ref":"Atex.AtURI.html#match?/1-examples"},{"type":"function","title":"Atex.AtURI.new/1","doc":"Create a new AtURI struct from a string by matching it against the regex.\n\nReturns `{:ok, aturi}` if a valid `at://` URI is given, otherwise it will return `:error`.","ref":"Atex.AtURI.html#new/1"},{"type":"function","title":"Examples - Atex.AtURI.new/1","doc":"iex> Atex.AtURI.new(\"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\")\n    {:ok, %Atex.AtURI{\n      rkey: \"3jwdwj2ctlk26\",\n      collection: \"app.bsky.feed.post\",\n      authority: \"did:plc:44ybard66vv44zksje25o7dz\"\n    }}\n\n    iex> Atex.AtURI.new(\"at:invalid/malformed\")\n    :error\n\nPartial URIs pointing to a collection without a record key, or even just a given authority, are also supported:\n\n    iex> Atex.AtURI.new(\"at://ovyerus.com/sh.comet.v0.feed.track\")\n    {:ok, %Atex.AtURI{\n      rkey: nil,\n      collection: \"sh.comet.v0.feed.track\",\n      authority: \"ovyerus.com\"\n    }}\n\n    iex> Atex.AtURI.new(\"at://did:web:comet.sh\")\n    {:ok, %Atex.AtURI{\n      rkey: nil,\n      collection: nil,\n      authority: \"did:web:comet.sh\"\n    }}","ref":"Atex.AtURI.html#new/1-examples"},{"type":"function","title":"Atex.AtURI.new!/1","doc":"The same as `new/1` but raises an `ArgumentError` if an invalid string is given.","ref":"Atex.AtURI.html#new!/1"},{"type":"function","title":"Examples - Atex.AtURI.new!/1","doc":"iex> Atex.AtURI.new!(\"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\")\n    %Atex.AtURI{\n      rkey: \"3jwdwj2ctlk26\",\n      collection: \"app.bsky.feed.post\",\n      authority: \"did:plc:44ybard66vv44zksje25o7dz\"\n    }\n\n    iex> Atex.AtURI.new!(\"at:invalid/malformed\")\n    ** (ArgumentError) Malformed at:// URI","ref":"Atex.AtURI.html#new!/1-examples"},{"type":"type","title":"Atex.AtURI.t/0","doc":"","ref":"Atex.AtURI.html#t:t/0"},{"type":"function","title":"Atex.AtURI.to_string/1","doc":"Format an `Atex.AtURI` to the canonical string representation.\n\nAlso available via the `String.Chars` protocol.","ref":"Atex.AtURI.html#to_string/1"},{"type":"function","title":"Examples - Atex.AtURI.to_string/1","doc":"iex> aturi = %Atex.AtURI{\n    ...>   rkey: \"3jwdwj2ctlk26\",\n    ...>   collection: \"app.bsky.feed.post\",\n    ...>   authority: \"did:plc:44ybard66vv44zksje25o7dz\"\n    ...> }\n    iex> Atex.AtURI.to_string(aturi)\n    \"at://did:plc:44ybard66vv44zksje25o7dz/app.bsky.feed.post/3jwdwj2ctlk26\"\n\n    iex> aturi = %Atex.AtURI{authority: \"did:web:comet.sh\"}\n    iex> to_string(aturi)\n    \"at://did:web:comet.sh\"","ref":"Atex.AtURI.html#to_string/1-examples"},{"type":"extras","title":"License","doc":"Copyright 2025 comet.sh\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the “Software”), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of\nthe Software, and to permit persons to whom the Software is furnished to do so,\nsubject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\nFOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER\nIN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\nCONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# atex\n\nA set of utilities for working with the [AT Protocol](https://atproto.com) in\nElixir.","ref":"readme.html"},{"type":"extras","title":"Current Roadmap (in no particular order) - Overview","doc":"- [x] `at://` parsing and struct\n- [ ] XRPC client\n- [ ] CID & TID codecs\n- [ ] DID & handle resolution service with a cache\n- [ ] Structs with validation for the common lexicons\n  - [ ] Probably codegen for doing this with other lexicons\n- [ ] Oauth stuff","ref":"readme.html#current-roadmap-in-no-particular-order"},{"type":"extras","title":"Installation - Overview","doc":"Get atex from [hex.pm](https://hex.pm) by adding it to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:atex, \"~> 0.1\"}\n  ]\nend\n```\n\nDocumentation can be found on HexDocs at https://hexdocs.pm/atex.\n\n---\n\nThis project is licensed under the [MIT License](./LICENSE).","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}